@@ -3,7 +3,7 @@
 ##                                                                          ##
 ##          MATLAB Independent, Small & Safe, High Integrity Tools          ##
 ##                                                                          ##
-##              Copyright (C) 2019-2021, Florian Schanda                    ##
+##              Copyright (C) 2019-2022, Florian Schanda                    ##
 ##              Copyright (C) 2019-2020, Zenuity AB                         ##
 ##                                                                          ##
 ##  This file is part of MISS_HIT.                                          ##
@@ -30,6 +30,7 @@ from miss_hit_core import pathutil
 from miss_hit_core.config import Config, METRICS
 from miss_hit_core.errors import ICE, Message_Handler
 from miss_hit_core.m_ast import *
+from miss_hit_core.m_language import Language
 from miss_hit_core.m_lexer import Token_Generator
 
 
@@ -92,6 +93,7 @@ class MATLAB_Parser:
         assert isinstance(cfg, Config)
 
         self.lexer = lexer
+        self.language = self.lexer.language
         self.mh    = mh
         self.cfg   = cfg
 
@@ -207,7 +209,7 @@ class MATLAB_Parser:
                 break
 
     def match(self, kind, value=None):
-        assert kind in TOKEN_KINDS
+        assert kind in self.language.token_kinds
         self.skip()
         if self.ct is None:
             self.mh.error(self.lexer.get_file_loc(),
@@ -233,7 +235,7 @@ class MATLAB_Parser:
                           (kind, value, self.ct.kind, self.ct.value))
 
     def amatch(self, kind, value=None):
-        assert kind in TOKEN_KINDS
+        assert kind in self.language.token_kinds
         self.skip()
         if self.ct is None:
             self.mh.error(self.lexer.get_file_loc(),
@@ -275,7 +277,7 @@ class MATLAB_Parser:
         return self.nt and self.nt.annotation
 
     def peek(self, kind, value=None):
-        assert kind in TOKEN_KINDS
+        assert kind in self.language.token_kinds
         if self.nt and \
            self.nt.kind == kind and \
            not self.nt.annotation:
@@ -287,7 +289,7 @@ class MATLAB_Parser:
             return False
 
     def peek2(self, kind, value=None):
-        assert kind in TOKEN_KINDS
+        assert kind in self.language.token_kinds
         if self.nnt and \
            self.nnt.kind == kind and \
            not self.nnt.annotation:
@@ -299,7 +301,7 @@ class MATLAB_Parser:
             return False
 
     def apeek(self, kind, value=None):
-        assert kind in TOKEN_KINDS
+        assert kind in self.language.token_kinds
         if self.nt and \
            self.nt.kind == kind and \
            self.nt.annotation:
@@ -332,6 +334,7 @@ class MATLAB_Parser:
            n_expr.t_bracket_open:
             self.mh.style_issue(n_expr.t_bracket_open.location,
                                 "redundant parenthesis",
+                                "redundant_brackets",
                                 True)
             n_expr.t_bracket_open.fix.delete = True
             n_expr.t_bracket_close.fix.delete = True
@@ -395,6 +398,7 @@ class MATLAB_Parser:
                             ending_token.fix.add_newline = True
                         self.mh.style_issue(ending_token.location,
                                             "end this with a ; and newline",
+                                            "end_of_statements",
                                             True)
                     else:
                         fixed = False
@@ -403,6 +407,7 @@ class MATLAB_Parser:
                             fixed = True
                         self.mh.style_issue(ending_token.location,
                                             "end statement with a newline",
+                                            "end_of_statements",
                                             fixed)
                 return
             elif self.peek_eof():
@@ -428,6 +433,7 @@ class MATLAB_Parser:
                 self.mh.style_issue(terminator_tokens[0].location,
                                     "end this with a semicolon"
                                     " instead of a comma",
+                                    "end_of_statements",
                                     True)
                 terminator_tokens[0].fix.change_to_semicolon = True
 
@@ -435,6 +441,7 @@ class MATLAB_Parser:
                 assert terminator_tokens[0].kind == "NEWLINE"
                 self.mh.style_issue(ending_token.location,
                                     "end statement with a semicolon",
+                                    "end_of_statements",
                                     True)
                 ending_token.fix.add_semicolon_after = True
 
@@ -445,6 +452,7 @@ class MATLAB_Parser:
                     fixed = True
                 self.mh.style_issue(terminator_tokens[0].location,
                                     "end statement with a newline",
+                                    "end_of_statements",
                                     fixed)
 
         else:
@@ -458,6 +466,7 @@ class MATLAB_Parser:
                 # the comma
                 self.mh.style_issue(ending_token.location,
                                     "end this with just a newline",
+                                    "end_of_statements",
                                     False)
                 if first_newline is None:
                     terminator_tokens[0].fix.change_to_semicolon = True
@@ -476,12 +485,14 @@ class MATLAB_Parser:
                     fixed = True
                 self.mh.style_issue(terminator_tokens[0].location,
                                     "end this with just a newline",
+                                    "end_of_statements",
                                     fixed)
 
         for terminator in terminator_tokens[1:]:
             if terminator.kind != "NEWLINE":
                 self.mh.style_issue(terminator.location,  # Molten steel?
                                     "unnecessary statement terminator",
+                                    "end_of_statements",
                                     True)
                 terminator.fix.delete = True
 
@@ -630,7 +641,7 @@ class MATLAB_Parser:
                                   l_pragmas + l_more_pragmas)
         elif self.peek("KEYWORD", "classdef"):
             cunit = self.parse_class_file(l_pragmas)
-        elif self.lexer.octave_mode:
+        elif self.language.script_global_functions:
             cunit = self.parse_octave_script_file(l_pragmas)
         else:
             cunit = self.parse_matlab_script_file(l_pragmas)
@@ -641,7 +652,7 @@ class MATLAB_Parser:
                 self.mh.error(cunit.l_functions[0].loc(),
                               "script-global functions are an Octave-specific"
                               " feature; move your functions to the end of"
-                              " the script file or use the --octave mode")
+                              " the script file or use an Octave language")
 
         if self.debug_tree:
             cunit.debug_parse_tree()
@@ -718,7 +729,12 @@ class MATLAB_Parser:
         self.functions_require_end = True
 
         n_classdef                  = self.parse_classdef()
-        l_functions, l_more_pragmas = self.parse_function_list()
+
+        if self.language.allow_classdef_subfunctions:
+            l_functions, l_more_pragmas = self.parse_function_list()
+        else:
+            l_functions    = []
+            l_more_pragmas = []
 
         return Class_File(os.path.basename(self.lexer.filename),
                           os.path.dirname(
@@ -1621,6 +1637,7 @@ class MATLAB_Parser:
                 self.mh.check(t_op.location,
                               "chained relation does not work the"
                               " way you think it does",
+                              "chained_relation",
                               "high")
 
         return rv
@@ -1869,7 +1886,7 @@ class MATLAB_Parser:
             return args
 
         while True:
-            if not self.lexer.octave_mode and \
+            if self.language.string_argument_pairs and \
                self.peek("IDENTIFIER") and self.peek2("ASSIGNMENT"):
                 # Special case for the 2021a MATLAB mis-feature of
                 # name-value pairs in function calls
@@ -1883,6 +1900,7 @@ class MATLAB_Parser:
                               "name-value pairs have extremely confusing"
                               " semantics and should be avoided, use two"
                               " arguments instead",
+                              "name_value_pairs",
                               severity="low")
 
                 nv_pair.set_value(t_eq, self.parse_expression())
